
/*
 *   OpenJupes v1.1
 *
 *   Server and Nickname Jupe Service for Ratbox v2+services.
 *   Copyright (C) 2005 Thomas Carlsson, Joost Vunderink and Alan Milford
 *
 *   NOTE: This service depends heavily on the +services patch by Lee
 *   Hardy. It will not compile without it.
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */


	struct IRCD_Data
	{
		void*	data;
	};

	struct OJ_nickjupe
	{
		char				nick[NICKLEN + 1];
		char				user[USERLEN + 1];
		char				host[HOSTLEN + 1];
		char				gecos[REALLEN + 1];
		int					type;					/* JUPETYPE */
		void*				data;					/* ircd-specific data structure */
	};

	struct OJ_voter
	{
		char				nick[NICKLEN + 1];
		char				user[USERLEN + 1];
		char				host[HOSTLEN + 1];
		char				server[HOSTLEN + 1];
		int					score;
		unsigned long		timestamp;
	};

	struct OJ_serverjupe
	{
		char				server[HOSTLEN + 1];
		char				reason[IRCLINELEN + 1];
		unsigned long		timestamp;
		unsigned long		expiration;				/* expiration date */

		struct OJ_voter		projupe[5];				
		struct OJ_voter		antijupe[5];

		void*				data;					/* ircd-specific data structure (only used for active jupes) */
	};

	struct OJ_jupes
	{
		/* Currently active nickname jupes */
		struct OJ_nickjupe*		nickname_active;
		int						nickname_activecount;
		int						nickname_activemax;
		
		/* Currently active server jupes */
		struct OJ_serverjupe*	server_active;
		int						server_activecount;
		int						server_activemax;

		/* Historical record of server jupes */
		struct OJ_serverjupe	server_history[JUPE_HISTORYMAX];
		int						server_historycount;
	};


	void OJ_Initialize();
	void OJ_Deinitialize();

	void OJ_LoadDB();
	void OJ_SaveDB();

	void OJ_CreateNickJupes( struct OJ_Conf* conf );
	void OJ_DeleteNickJupes( struct OJ_Conf* conf );

	void OJ_Vote( char* jupeserver, char* jupereason, struct OJ_voter* voter );
	void OJ_ExpireVotes();

	void OJ_GetActive( struct IRCD_Data* id );
	void OJ_GetHistory( struct IRCD_Data* id, int wantedcount );

	int OJ_IsJuped( char* jupeserver );

